@@ -3,8 +3,7 @@ Wire this into the root URLConf this way::
 
     url(r'^stripe/', include('djstripe.urls', namespace="djstripe")),
     # url can be changed
-    # namespace can be changed
-    # Call to 'djstripe.urls' must stay as is
+    # Call to 'djstripe.urls' and 'namespace' must stay as is
 
 Call it from reverse()::
 
@@ -24,6 +23,11 @@ from . import views
 
 
 urlpatterns = patterns("",
+    url(
+        r"^$",
+        views.AccountView.as_view(),
+        name="account"
+    ),
     url(
         r"^subscribe/$",
         views.SubscribeFormView.as_view(),
@@ -44,9 +48,15 @@ urlpatterns = patterns("",
         views.HistoryView.as_view(),
         name="history"
     ),
+    url(
+        r"^a/sync_history/$",
+        views.SyncHistoryView.as_view(),
+        name="sync_history"
+    ),
     url(
         app_settings.DJSTRIPE_WEBHOOK_URL,
         views.WebHook.as_view(),
         name="webhook"
     ),
+
 )
\ No newline at end of file
