@@ -1,23 +1,32 @@
 from __future__ import unicode_literals
 from django.contrib import messages
+from django.core.exceptions import ImproperlyConfigured
 from django.shortcuts import redirect
 
 from .models import Customer
 from . import settings as app_settings
 
+ERROR_MSG = (
+                "SubscriptionPaymentRequiredMixin requires the user be"
+                "authenticated before use. Please use django-braces'"
+                "LoginRequiredMixin."
+            )
 
-class PaymentRequiredMixin(object):
+
+class SubscriptionPaymentRequiredMixin(object):
     """ Used to check to see if someone paid """
+    # TODO - needs tests
     def dispatch(self, request, *args, **kwargs):
-        customer, create = Customer.objects.get_or_create(
-            user=request.user
-        )
-        if not customer.has_active_subscription():
+        if request.user.is_anonymous():
+            raise ImproperlyConfigured(ERROR_MSG)
+
+        customer, created = Customer.get_or_create(request.user)
+        if created or not customer.has_active_subscription():
             msg = "Your account is inactive. Please renew your subscription"
             messages.info(request, msg, fail_silently=True)
-            return redirect("subscriptions:subscribe")
+            return redirect("djstripe:subscribe")
 
-        return super(PaymentRequiredMixin, self).dispatch(
+        return super(SubscriptionPaymentRequiredMixin, self).dispatch(
             request, *args, **kwargs)
 
 
